<?php

class Custom_Recent_Interviews_Widget extends WP_Widget {

    function __construct() {
        $widget_ops = array(
            'classname' => 'widget_recent_entries',
            'description' => __('Выводит список записей из одной или более отмеченных рубрик.')
        );
        parent::__construct('custom-recent-interviews', __('Custom Recent Interviews'), $widget_ops);
    }

    function widget($args, $instance) {

        extract($args);

        $title = apply_filters('widget_title', empty($instance['title']) ? 'Recent Interviews' : $instance['title'], $instance, $this->id_base);
        $show_date = isset($instance['show_date']) ? $instance['show_date'] : false;

        if (!$number = absint($instance['number']))
            $number = 5;

        if (!$cats = $instance['cats'])
            $cats = '';
//echo '</pre>';
//print_r($instance['cats']);
//echo '</pre>';
        // array to call recent interviews.

        $criw_args = array(
            'showposts' => $number,
            'category__in' => $cats,
        );

        $cri_widget = null;
        $cri_widget = new WP_Query($criw_args);

        echo $before_widget;

        // Widget title
        if ($instance["title"]) {
            echo $before_title;
            echo $instance["title"];
            echo $after_title;
        }

        // HTML before list
        if ( $instance['html_before'] ) {
            echo '<div class="criw-html-before">';
            echo $instance['html_before'];
            echo '</div>';
        }

        // Interview list in widget

        echo "<ul class='criw-wrap'>\n";

        while ($cri_widget->have_posts()) {
            $cri_widget->the_post();
            ?>
            <li class="criw-item" style="clear: both;">
                <?php if (has_post_thumbnail() && $instance['show_thumbnail'] ) { ?>
                    <a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>" >
                        <?php
                        /* Делаем произвольные размеры (чтобы не писать в functions.php). Преимущество у ширины. */
                        add_image_size('interview-thumb', $instance["width"], $instance["height"], true);
                        add_action('after_setup_theme', 'interview-thumb');
                        the_post_thumbnail('interview-thumb', array('class' => 'criw-img'));
                        ?>
                    </a>
                <?php } ?>
                <a  href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>" class="criw-title"><?php the_title(); ?></a>
                <?php if ($show_date) : ?>
                    <br /><span class="criw-date"><?php echo "("; ?><?php echo get_the_date(); ?><?php echo ")"; ?></span>
                <?php endif; ?>
                <?php if ($instance['show_preview']) : ?>
                    <div class="criw-preview" style="clear: both;">
                        <?php
                        if ($instance['show_preview_from']) {$anouncement = get_the_content();} else {$anouncement = get_the_excerpt();}
                        if ($instance['max_words_preview'] > 0) {
                            $charlength++;
                            if (mb_strlen($anouncement) > $charlength) {
                                $words = explode(' ', $anouncement, ($instance['max_words_preview'] + 1));
                                if (count($words) > $instance['max_words_preview'])
                                    array_pop($words);
                                echo implode(' ', $words) . ' …';
                            }
                        } else {
                            echo $anouncement;
                        }
                        ?>
                    </div>
            <?php endif; ?>
            </li>
            <?php
        }

        wp_reset_query();

        echo "</ul>\n";

        // HTML after list
        if ( $instance['html_after'] ) {
            echo '<div class="criw-html-after">';
            echo $instance['html_after'];
            echo '</div>';
        }

        echo $after_widget;
    }

    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $instance['cats'] = $new_instance['cats'];
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['html_before'] = $new_instance['html_before'];
        $instance['tags'] = $new_instance['tags'];
        $instance['number'] = absint($new_instance['number']);
        $instance['show_thumbnail'] = (bool) $new_instance['show_thumbnail'];
        $instance['width'] = absint($new_instance['width']);
        $instance['height'] = absint($new_instance['height']);
        $instance['show_date'] = (bool) $new_instance['show_date'];
        $instance['show_preview'] = (bool) $new_instance['show_preview'];
        $instance['show_preview_from'] = (bool) $new_instance['show_preview_from'];
        $instance['max_words_preview'] = absint($new_instance['max_words_preview']);
        $instance['html_after'] = $new_instance['html_after'];

        return $instance;
    }

    function form($instance) {
        $title = isset($instance['title']) ? esc_attr($instance['title']) : 'Новые интервью';
        $number = isset($instance['number']) ? absint($instance['number']) : 5;
        $show_date = isset($instance['show_date']) ? (bool) $instance['show_date'] : false;
        ?>
        <p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></p>

        <p><label for="<?php echo $this->get_field_id('html_before'); ?>"><?php _e('HTML код перед списком:'); ?></label>
            <textarea id="<?php echo $this->get_field_id('html_before'); ?>" name="<?php echo $this->get_field_name('html_before'); ?>" type="text"><?php echo $instance['html_before']; ?></textarea><p>

        <p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Количество интервью:'); ?></label>
            <input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /></p>

        <p><input class="checkbox" type="checkbox" <?php checked($instance['show_thumbnail']); ?> id="<?php echo $this->get_field_id('show_thumbnail'); ?>" name="<?php echo $this->get_field_name('show_thumbnail'); ?>" />
            <label for="<?php echo $this->get_field_id('show_thumbnail'); ?>"><?php _e('Показать миниатюру?'); ?></label></p>
        
        <p><label for="<?php echo $this->get_field_id('width'); ?>"><?php _e('Ширина изображения:'); ?></label>
            <input id="<?php echo $this->get_field_id('width'); ?>" name="<?php echo $this->get_field_name('width'); ?>" type="text" value="<?php echo $instance['width']; ?>" size="4" />px</p>
        <p><label for="<?php echo $this->get_field_id('height'); ?>"><?php _e('Высота изображения:'); ?></label>
            <input id="<?php echo $this->get_field_id('height'); ?>" name="<?php echo $this->get_field_name('height'); ?>" type="text" value="<?php echo $instance['height']; ?>" size="4" />px</p>

        <p><input class="checkbox" type="checkbox" <?php checked($show_date); ?> id="<?php echo $this->get_field_id('show_date'); ?>" name="<?php echo $this->get_field_name('show_date'); ?>" />
            <label for="<?php echo $this->get_field_id('show_date'); ?>"><?php _e('Показать дату?'); ?></label></p>

        <p><input class="checkbox" type="checkbox" <?php checked($instance['show_preview']); ?> id="<?php echo $this->get_field_id('show_preview'); ?>" name="<?php echo $this->get_field_name('show_preview'); ?>" />
            <label for="<?php echo $this->get_field_id('show_preview'); ?>"><?php _e('Показать анонс?'); ?></label></p>

        <div style="padding-left: 10px;">
            <div style="float:left; width:25px; text-align: right; padding-top: 0.7em;">
                <input class="checkbox" type="checkbox" <?php checked($instance['show_preview_from']); ?> id="<?php echo $this->get_field_id('show_preview_from'); ?>" name="<?php echo $this->get_field_name('show_preview_from'); ?>" />
            </div>
            <div style="float:left;">
                <label for="<?php echo $this->get_field_id('show_preview_from'); ?>">
                    <b>ВКЛ:</b> из контента<br />
                    <b>ВЫКЛ:</b> из Цитаты
                </label>
            </div>
            <div style="clear:both; color:red;"><b><u>ВАЖНО!</u> Разметка из контента <u>сохраняется</u>!</b></div>
        </div>
        
        <p><label for="<?php echo $this->get_field_id('max_words_preview'); ?>"><?php _e('Количество слов в анонсе <br />(0 - весь анонс):'); ?></label>
            <input id="<?php echo $this->get_field_id('max_words_preview'); ?>" name="<?php echo $this->get_field_name('max_words_preview'); ?>" type="text" value="<?php echo $instance['max_words_preview']; ?>" size="4" /></p>

        <p>
            <label for="<?php echo $this->get_field_id('cats'); ?>"><?php _e('Из каких рубрик выводить интервью:'); ?> 

                <?php
                $categories = get_categories('hide_empty=0');
                echo "<br/>";
                foreach ($categories as $cat) {
                    $option = '<input type="checkbox" id="' . $this->get_field_id('cats') . '[]" name="' . $this->get_field_name('cats') . '[]"';
                    if (is_array($instance['cats'])) {
                        foreach ($instance['cats'] as $cats) {
                            if ($cats == $cat->term_id) {
                                $option = $option . ' checked="checked"';
                            }
                        }
                    }
                    $option .= ' value="' . $cat->term_id . '" />';
                    $option .= '&nbsp;';
                    $option .= $cat->cat_name;
                    $option .= '<br />';
                    echo $option;
                }
                ?>
            </label>
        </p>

        <p><label for="<?php echo $this->get_field_id('html_after'); ?>"><?php _e('HTML код после списка:'); ?></label>
            <textarea id="<?php echo $this->get_field_id('html_after'); ?>" name="<?php echo $this->get_field_name('html_after'); ?>" type="text"><?php echo $instance['html_after']; ?></textarea><p>

            <?php
        }

    }

    function criw_register_widgets() {
        register_widget('Custom_Recent_Interviews_Widget');
    }

    add_action('widgets_init', 'criw_register_widgets');
    ?>
