<?php

class CRIW_Tags_Widget extends WP_Widget {

    function __construct() {
        $widget_ops = array(
            'classname' => 'widget_recent_entries',
            'description' => __('Выводит список записей, отмеченных выбранными тегами.')
        );
        parent::__construct('recent-interviews-by-tags', __('Custom Recent Interviews by Tags'), $widget_ops);
    }

    function widget($args, $instance) {

        extract($args);

        $title = apply_filters('widget_title', empty($instance['title']) ? 'Recent Interviews' : $instance['title'], $instance, $this->id_base);
        $show_date = isset($instance['show_date']) ? $instance['show_date'] : false;

        if (!$number = absint($instance['number']))
            $number = 5;

        if (!$tags = $instance["tags"])
            $tags = '';

        // array to call recent interviews.

        $criw_tag_args = array(
            'showposts' => $number,
            'tag__in' => $tags,
        );

        $criw_tag_widget = null;
        $criw_tag_widget = new WP_Query($criw_tag_args);

        echo $before_widget;

        // Widget title
        if ($instance["title"]) {
            echo $before_title;
            echo $instance["title"];
            echo $after_title;
        }

        // HTML before list
        if ($instance['html_before']) {
            echo '<div class="criw-tag-html-before">';
            echo $instance['html_before'];
            echo '</div>';
        }

        // Interview list in widget

        echo "<ul class='criw-tag-wrap'>\n";

        while ($criw_tag_widget->have_posts()) {
            $criw_tag_widget->the_post();
            ?>
            <li class="criw-tag-item" style="clear: both;">
                <?php if (has_post_thumbnail() && $instance['show_thumbnail']) { ?>
                    <a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>" >
                        <?php
                        /* Делаем произвольные размеры (чтобы не писать в functions.php). Преимущество у ширины. */
                        add_image_size('interview-thumb-tag', $instance["width"], $instance["height"], true);
                        add_action('after_setup_theme', 'interview-thumb-tag');
                        the_post_thumbnail('interview-thumb-tag', array('class' => 'criw-tag-img'));
                        ?>
                    </a>
                <?php } ?>
                <a  href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>" class="criw-tag-title"><?php the_title(); ?></a>
                <?php if ($show_date) : ?>
                    <br /><span class="criw-tag-date"><?php echo "("; ?><?php echo get_the_date(); ?><?php echo ")"; ?></span>
                <?php endif; ?>
                <?php if ($instance['show_preview']) : ?>
                    <div class="criw-tag-preview" style="clear: both;">
                        <?php
                        if ($instance['show_preview_from']) {$anouncement = get_the_content();} else {$anouncement = get_the_excerpt();}
                        if ($instance['max_words_preview'] > 0) {
                            $charlength++;
                            if (mb_strlen($anouncement) > $charlength) {
                                $words = explode(' ', $anouncement, ($instance['max_words_preview'] + 1));
                                if (count($words) > $instance['max_words_preview'])
                                    array_pop($words);
                                echo implode(' ', $words) . ' …';
                            }
                        } else {
                            echo $anouncement;
                        }
                        ?>
                    </div>
            <?php endif; ?>
            </li>
            <?php
        }

        wp_reset_query();

        echo "</ul>\n";

        // HTML after list
        if ($instance['html_after']) {
            echo '<div class="criw-tag-html-after">';
            echo $instance['html_after'];
            echo '</div>';
        }

        echo $after_widget;
    }

    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['html_before'] = $new_instance['html_before'];
        $instance['tags'] = $new_instance['tags'];
        $instance['number'] = absint($new_instance['number']);
        $instance['show_thumbnail'] = (bool) $new_instance['show_thumbnail'];
        $instance['width'] = absint($new_instance['width']);
        $instance['height'] = absint($new_instance['height']);
        $instance['show_date'] = (bool) $new_instance['show_date'];
        $instance['show_preview'] = (bool) $new_instance['show_preview'];
        $instance['show_preview_from'] = (bool) $new_instance['show_preview_from'];
        $instance['max_words_preview'] = absint($new_instance['max_words_preview']);
        $instance['html_after'] = $new_instance['html_after'];

        return $instance;
    }

    function form($instance) {
        $title = isset($instance['title']) ? esc_attr($instance['title']) : 'Новые интервью';
        $number = isset($instance['number']) ? absint($instance['number']) : 5;
        $show_date = isset($instance['show_date']) ? (bool) $instance['show_date'] : false;
        ?>
        <p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></p>

        <p><label for="<?php echo $this->get_field_id('html_before'); ?>"><?php _e('HTML код перед списком:'); ?></label>
            <textarea id="<?php echo $this->get_field_id('html_before'); ?>" name="<?php echo $this->get_field_name('html_before'); ?>" type="text"><?php echo $instance['html_before']; ?></textarea><p>

        <p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Количество интервью:'); ?></label>
            <input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /></p>

        <p><input class="checkbox" type="checkbox" <?php checked($instance['show_thumbnail']); ?> id="<?php echo $this->get_field_id('show_thumbnail'); ?>" name="<?php echo $this->get_field_name('show_thumbnail'); ?>" />
            <label for="<?php echo $this->get_field_id('show_thumbnail'); ?>"><?php _e('Показать миниатюру?'); ?></label></p>

        <p style="margin-left: 10px;"><label for="<?php echo $this->get_field_id('width'); ?>"><?php _e('Ширина изображения:'); ?></label>
            <input id="<?php echo $this->get_field_id('width'); ?>" name="<?php echo $this->get_field_name('width'); ?>" type="text" value="<?php echo $instance['width']; ?>" size="4" />px</p>
        <p style="margin-left: 10px;"><label for="<?php echo $this->get_field_id('height'); ?>"><?php _e('Высота изображения:'); ?></label>
            <input id="<?php echo $this->get_field_id('height'); ?>" name="<?php echo $this->get_field_name('height'); ?>" type="text" value="<?php echo $instance['height']; ?>" size="4" />px</p>

        <p><input class="checkbox" type="checkbox" <?php checked($show_date); ?> id="<?php echo $this->get_field_id('show_date'); ?>" name="<?php echo $this->get_field_name('show_date'); ?>" />
            <label for="<?php echo $this->get_field_id('show_date'); ?>"><?php _e('Показать дату?'); ?></label></p>

        <p><input class="checkbox" type="checkbox" <?php checked($instance['show_preview']); ?> id="<?php echo $this->get_field_id('show_preview'); ?>" name="<?php echo $this->get_field_name('show_preview'); ?>" />
            <label for="<?php echo $this->get_field_id('show_preview'); ?>"><?php _e('Показать анонс?'); ?></label></p>

        <div style="padding-left: 10px;">
            <div style="float:left; width:25px; text-align: right; padding-top: 0.7em;">
                <input class="checkbox" type="checkbox" <?php checked($instance['show_preview_from']); ?> id="<?php echo $this->get_field_id('show_preview_from'); ?>" name="<?php echo $this->get_field_name('show_preview_from'); ?>" />
            </div>
            <div style="float:left;">
                <label for="<?php echo $this->get_field_id('show_preview_from'); ?>">
                    <b>ВКЛ:</b> из контента<br />
                    <b>ВЫКЛ:</b> из Цитаты
                </label>
            </div>
             <div style="clear:both; color:red;"><b><u>ВАЖНО!</u> Разметка из контента <u>сохраняется</u>!</b></div>
        </div>

        <p style="margin-left: 10px;"><label for="<?php echo $this->get_field_id('max_words_preview'); ?>"><?php _e('Количество слов в анонсе <br />(0 - весь анонс):'); ?></label>
            <input id="<?php echo $this->get_field_id('max_words_preview'); ?>" name="<?php echo $this->get_field_name('max_words_preview'); ?>" type="text" value="<?php echo $instance['max_words_preview']; ?>" size="4" /></p>

        <p>
            <label for="<?php echo $this->get_field_id('tags'); ?>"><?php _e('Из каких рубрик выводить интервью:'); ?> 

                <?php
                $tags = get_tags('hide_empty=0');
                echo "<br/>";
                foreach ($tags as $tag) {
                    $option = '<input type="checkbox" id="' . $this->get_field_id('tags') . '[]" name="' . $this->get_field_name('tags') . '[]"';
                    if (is_array($instance['tags'])) {
                        foreach ($instance['tags'] as $tags) {
                            if ($tags == $tag->term_id) {
                                $option = $option . ' checked="checked"';
                            }
                        }
                    }
                    $option .= ' value="' . $tag->term_id . '" />';
                    $option .= '&nbsp;';
                    $option .= $tag->name . ' ';
                    $option .= '<br />';
                    echo $option;
                }
                ?>
            </label>
        </p>

        <p><label for="<?php echo $this->get_field_id('html_after'); ?>"><?php _e('HTML код после списка:'); ?></label>
            <textarea id="<?php echo $this->get_field_id('html_after'); ?>" name="<?php echo $this->get_field_name('html_after'); ?>" type="text"><?php echo $instance['html_after']; ?></textarea><p>

            <?php
        }

    }

    function criw_tag_register_widget() {
        register_widget('CRIW_Tags_Widget');
    }

    add_action('widgets_init', 'criw_tag_register_widget');
    ?>
